
using System.Reflection;
using System.Diagnostics;
using System.IO;
using System.Threading;
using System.Windows.Forms;



// Creates a class to handle the exception event.
internal class clsCustomExceptionHandler
{

	private string mstrERROR_REPORTED = "Error reported: ";

	// Handles the exception event.
	public void OnThreadException(object sender, ThreadExceptionEventArgs t)
	{

		try
		{
			ShowThreadExceptionDialog(t.Exception);
		}
		catch
		{
			try
			{
				MessageBox.Show("Fatal Error", "Fatal Error", MessageBoxButtons.AbortRetryIgnore, MessageBoxIcon.Stop);
			}
			finally
			{
				Application.Exit();
			}
		}


	}


	// Creates the error message and displays it.
	private void ShowThreadExceptionDialog(System.Exception e)
	{


		StringWriter strResult = new StringWriter();

		strResult.WriteLine("An error occurred please contact the adminstrator with the following information:");
		strResult.WriteLine("");
		strResult.WriteLine(e.Message);
		strResult.WriteLine("");
		strResult.WriteLine("Stack Trace:");
		strResult.WriteLine(e.StackTrace);

		if (MessageBox.Show(strResult.ToString(), "Application Error", MessageBoxButtons.AbortRetryIgnore, MessageBoxIcon.Stop) == DialogResult.Abort)
		{

			Application.Exit();
		}

	}
	// Error handler routine based on Balena Chapter 15
	internal void ErrorHandler(System.Exception e)
	{

		int intMAX_LINES = 20;
		int intI, intFrameCount;
		string strResult=null;
		StackTrace stt;

		strResult += mstrERROR_REPORTED + System.Environment.NewLine + System.Environment.NewLine;

		// Write the error to the screen
		strResult += e.Message + System.Environment.NewLine + System.Environment.NewLine;

		if (e.InnerException != null)
		{

			strResult += e.InnerException.Message + System.Environment.NewLine + System.Environment.NewLine;
		}

		// Create a stack trace object
		stt = new StackTrace(e, true);

		// Iterate through stack
		intFrameCount = stt.FrameCount - 1;
		if (intFrameCount > intMAX_LINES)
			intFrameCount = intMAX_LINES;
		for (intI = 0; intI <= intFrameCount; intI++)
		{

			StackFrame stf;
			MemberInfo mbi;

			stf = stt.GetFrame(intI);
			mbi = stf.GetMethod();

			// Exclude .Net framework calls
			if (stf.GetFileName() != "")
			{

				strResult += mbi.DeclaringType.Name + ".";
				strResult += mbi.Name;
				strResult += '\r' + " (" + stf.GetFileName() + ", Line " + stf.GetFileLineNumber() + ")";
				strResult += '\r';

			}

		}

		strResult += System.Environment.NewLine + System.Environment.NewLine;

		Trace.WriteLine(strResult);

		if (MessageBox.Show(strResult.ToString(), "Application Error", MessageBoxButtons.AbortRetryIgnore, MessageBoxIcon.Stop) == DialogResult.Abort)
		{

			Application.Exit();
		}

	}


}





