
Imports System.Reflection
Imports System.Diagnostics
Imports System.IO
Imports System.Threading

' Creates a class to handle the exception event.
Friend Class clsCustomExceptionHandler

    Private mstrERROR_REPORTED As String = "Error reported: "

    ' Handles the exception event.
    Friend Sub OnThreadException(ByVal sender As Object, _
                                 ByVal t As ThreadExceptionEventArgs)


        Try

            ShowThreadExceptionDialog(t.Exception)

        Catch
            Try
                MessageBox.Show("Fatal Error", "Fatal Error", MessageBoxButtons.AbortRetryIgnore, MessageBoxIcon.Stop)
            Finally
                Application.Exit()
            End Try
        End Try


    End Sub


    ' Error handler routine based on Balena Chapter 15
    Friend Sub ErrorHandler(ByVal e As Exception)

        Dim intI As Integer
        Dim strResult As String
        Dim stt As StackTrace

        strResult &= mstrERROR_REPORTED & vbCrLf & vbCrLf

        ' Write the error to the screen
        strResult &= e.Message & vbCrLf & vbCrLf

        If Not e.InnerException Is Nothing Then

            strResult &= e.InnerException.Message & vbCrLf & vbCrLf
        End If

        ' Create a stack trace object
        stt = New StackTrace(e, True)

        ' Iterate through stack
        For intI = 0 To stt.FrameCount - 1

            Dim stf As StackFrame
            Dim mbi As MemberInfo

            stf = stt.GetFrame(intI)
            mbi = stf.GetMethod

            ' Exclude .Net framework calls
            If stf.GetFileName <> "" Then

                strResult &= mbi.DeclaringType.Name & "."
                strResult &= mbi.Name
                strResult &= Chr(13) & " (" & stf.GetFileName & ", Line " & stf.GetFileLineNumber & ")"
                strResult &= Chr(13)

            End If

        Next

        strResult &= vbCrLf & vbCrLf

        Trace.WriteLine(strResult)

        If MessageBox.Show(strResult.ToString(), "Application Error", _
                            MessageBoxButtons.AbortRetryIgnore, _
                            MessageBoxIcon.Stop) = DialogResult.Abort Then

            Application.Exit()
        End If

    End Sub


    ' Creates the error message and displays it.
    Private Sub ShowThreadExceptionDialog(ByVal e As Exception)

        Dim strResult As StringWriter = New StringWriter

        strResult.WriteLine("An error occurred please contact the adminstrator with the following information:")
        strResult.WriteLine("")
        strResult.WriteLine(e.Message)
        strResult.WriteLine("")
        strResult.WriteLine("Stack Trace:")
        strResult.WriteLine(e.StackTrace)

        If MessageBox.Show(strResult.ToString(), "Application Error", _
                            MessageBoxButtons.AbortRetryIgnore, _
                            MessageBoxIcon.Stop) = DialogResult.Abort Then

            Application.Exit()
        End If

    End Sub

End Class




